/* Copyright 2007 Ricardo Baratto */
/* Copyright 2007 Columbia University */
/*
 * Authors: 
 * Ricardo Baratto - Network Computing Lab - Columbia University
 */
/* set tabstop = 8 */

#ifndef _THINC_SOUND_COMMON_H_
#define _THINC_SOUND_COMMON_H_

#include "thincSound.h"
#include "thincProto.h"
#include "thincProtoSound.h"
#include "thincCommon.h"

/* Defines */
#define OPENED_PLAYBACK 1
#define OPENED_CAPTURE  2

/* where we expect the unix socket to be */
#define SOCKET_DIR	"/tmp/thinc/"
#define SOCKET_PATH	SOCKET_DIR "sound."

#include <config.h>

/* Debug (./configure --enable-debug) */
#ifdef DEBUG
#define s_dbg(fmt, arg...) 				\
	printf("DEBUG[%d]: %s: " fmt, getpid(), __FUNCTION__ , ## arg)
#else
#define s_dbg(fmt, arg...)
#endif
#define s_err(...) printf("Error: " __VA_ARGS__)
#define s_msg(...) printf(__VA_ARGS__)
#define s_warn(...) printf("Warning: " __VA_ARGS__)

/* args are unsigned long. yes, there's overflow but since it's all relative
 * we care not much. we also use shift to mimic * and / with powers of 10. */
#include <sys/time.h>
#include <time.h>

#define gettime_ms(t) do { \
    struct timeval __tv;        \
    gettimeofday(&__tv, NULL);  \
    t = (__tv.tv_sec<<10) + (__tv.tv_usec>>10); \
} while(0)

/* gettime in microseconds */
#define gettime_us(t) do { \
    struct timeval __tv;        \
    gettimeofday(&__tv, NULL);  \
    t = (__tv.tv_sec<<20) + (__tv.tv_usec); \
} while(0)

/* for backtrace */
#include <execinfo.h>

/* useful for debugging */
#define print_stack() do { \
	void *trace[16]; \
	char **messages; \
	int i, trace_size; \
	trace_size = backtrace(trace, 16); \
	messages = backtrace_symbols(trace, trace_size); \
	s_dbg("backtrace\n"); \
	for(i=0; i<trace_size; ++i) \
		s_dbg("=> [%d] %s\n", i, messages[i]); \
	free(messages); \
} while(0)



#endif /* _THINC_SOUND_COMMON_H_ */
